%takes slice of psf of rotationally symmetric psf and rotates it to 2D.
%It needs the psf (psf) and the radial axis in units of pixels (rx)
%https://www.strollswithmydog.com/estimate-lens-psf

psf = o.psf;                    %1D slice of psf intensity
rx = o.r/o.pitch;               %pixels, psf positive x-axis

sub = 8;                        %sub/pixel, subsampling of psf
r = 4;                          %pixels, cutoff radius of psf

xm = -r:1/sub:r-1/sub;          %subsampled axes
[X,Y] = meshgrid(xm);
RHO = sqrt(X.^2 + Y.^2);        %radial distance of each pix in psf

PSF = interp1(rx,psf,RHO);      %rotate 1D psf into 2D PSF
PSF(isnan(PSF)) = 0;
PSF = PSF / sum(sum(PSF));      %normalize area to 1

figure; mesh(xm,xm,PSF)
xlabel('pixels'); ylabel('pixels'); zlabel('Relative Intensity')
title('Normalized PSF from Rotated Radial Slice')

figure; imshow(PSF.^0.45,[])
title('Lens PSF')
